var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React, { Component } from 'react';
import { SuggesterContext } from './SuggesterContext';
import { StyleSheet, Easing, Animated } from 'react-native';
import { SuggesterModal } from './SuggesterModal';
import { DURATION, WINDOW_HEIGHT, STATUS_BAR_HEIGHT } from './Constants';
import { setStateAsync } from './SetStateAsync';
import Fuse from 'fuse.js';
export class SuggesterProvider extends Component {
    constructor() {
        super(...arguments);
        this.state = {
            data: [],
            currentName: undefined,
            marginTop: 30,
            paddingHorizontal: 15,
            values: {},
            focused: false,
        };
        this.translateY = new Animated.Value(WINDOW_HEIGHT);
        this.opacity = new Animated.Value(0);
        this.setDataAsync = (name, data) => __awaiter(this, void 0, void 0, function* () {
            yield setStateAsync({ component: this, state: { data, currentName: name } });
            this.fuse = new Fuse(data, {
                shouldSort: true,
                threshold: 0.6,
                location: 0,
                distance: 100,
                maxPatternLength: 32,
                minMatchCharLength: 1,
                keys: ['value'],
            });
        });
        this.setValueAsync = (name, value) => setStateAsync({
            component: this,
            state: { values: Object.assign({}, this.state.values, { [name]: value }) },
        });
        this.setMarginTopAsync = (marginTop) => setStateAsync({ component: this, state: { marginTop } });
        this.handleFocus = () => __awaiter(this, void 0, void 0, function* () {
            const { marginTop } = this.state;
            yield setStateAsync({
                component: this,
                state: {
                    focused: true,
                },
            });
            Animated.parallel([
                Animated.timing(this.translateY, {
                    toValue: marginTop + this.props.statusBarHeight,
                    duration: DURATION,
                    easing: Easing.inOut(Easing.ease),
                    useNativeDriver: true,
                }),
                Animated.timing(this.opacity, {
                    toValue: 1,
                    duration: DURATION,
                    easing: Easing.inOut(Easing.ease),
                    useNativeDriver: true,
                }),
            ]).start();
        });
        this.handleBlur = () => {
            Animated.parallel([
                Animated.timing(this.translateY, {
                    toValue: WINDOW_HEIGHT,
                    duration: DURATION,
                    easing: Easing.inOut(Easing.ease),
                    useNativeDriver: true,
                }),
                Animated.timing(this.opacity, {
                    toValue: 0,
                    duration: DURATION,
                    easing: Easing.inOut(Easing.ease),
                    useNativeDriver: true,
                }),
            ]).start(({ finished }) => {
                if (finished) {
                    this.setState({ focused: false });
                }
            });
        };
        this.selectFromList = (name, value) => this.setValueAsync(name, value);
        this.getData = () => {
            const { values, currentName, data } = this.state;
            return this.fuse && currentName && values[currentName]
                ? this.fuse.search(values[currentName])
                : data;
        };
        this.setPaddingHorizontalAsync = (paddingHorizontal) => setStateAsync({ component: this, state: { paddingHorizontal } });
    }
    render() {
        const { children, backgroundColor, statusBarHeight, textWhenEmpty, textColor, textFont, textFontSize, } = this.props;
        const { values, currentName, paddingHorizontal, marginTop, focused, } = this.state;
        const { setDataAsync, setMarginTopAsync, selectFromList, handleFocus: handleFocusProvider, handleBlur: handleBlurProvider, setValueAsync, setPaddingHorizontalAsync, translateY, opacity, } = this;
        return (<SuggesterContext.Provider value={{
            backgroundColor,
            statusBarHeight,
            values,
            setDataAsync,
            setMarginTopAsync,
            setValueAsync,
            handleFocusProvider,
            handleBlurProvider,
            setPaddingHorizontalAsync,
        }}>
        {children}
        {focused && (<>
            <Animated.View style={Object.assign({}, StyleSheet.absoluteFillObject, { backgroundColor, zIndex: 400, transform: [{ translateY }] })}>
              <SuggesterModal {...{
            data: this.getData(),
            selectFromList,
            textWhenEmpty,
            backgroundColor,
            textColor,
            textFont,
            textFontSize,
            currentName,
            paddingHorizontal,
        }}/>
            </Animated.View>

            <Animated.View style={Object.assign({}, StyleSheet.absoluteFillObject, { bottom: undefined, height: statusBarHeight, backgroundColor,
            opacity })}/>
            <Animated.View style={Object.assign({}, StyleSheet.absoluteFillObject, { top: statusBarHeight, bottom: undefined, right: undefined, height: marginTop, width: paddingHorizontal, backgroundColor,
            opacity })}/>
            <Animated.View style={Object.assign({}, StyleSheet.absoluteFillObject, { top: statusBarHeight, bottom: undefined, left: undefined, height: marginTop, width: paddingHorizontal, backgroundColor,
            opacity })}/>
          </>)}
      </SuggesterContext.Provider>);
    }
}
SuggesterProvider.defaultProps = {
    statusBarHeight: STATUS_BAR_HEIGHT,
    backgroundColor: 'white',
    textColor: 'black',
};
//# sourceMappingURL=SuggesterProvider.js.map